//_AAA_CloseAll_ORDERS.mq4
//-
/*NOTES:Why close OrdersTotal-1...0 ? instead of 0...total-1
Because: IF we close order.zero and loop and now increment to order.one
note:At this time since we closed order.zero, OrdersTotal is now one less.
THEN before we close order.one, some other order closes due to TP or SL or...
BUT... and this is crucial: the list of orders *still* commences with order.zero!
Remember: we always use OrdersTotal-1...0, and effectively although we closed order.zero,
another order closes. This means that two orders have actually closed. Yet crucially, we have now
moved onto order.one but... order.zero still exists and we will never close it.
viz:
order pool positions: 0  1  2  3  4
open orders:					A  B  C  D  E
we close[4]:										  E
open orders:					A  B  C  D
order C self closes:  A  B  D
we 'attempt' close[3]:A  B  D				//but not happen as no order in pool slot [3], so we loop
we close[2]:          A  B
we close[1]:          A
we close[0]:          -							//done

SEE what is going on? After each close the orders are moved down towards [0].
ie, C self closes and D is now in [2] not [3]. Why? because only 3 orders left in pool: 0,1,2 and OrdersTotal()==3 (0..2)
By going HIGH -> LOW we are assured of always ending up at [0]: where the LAST order (if not self closed yet) will be.

Had we gone LOW -> HIGH we would actually be attempting to access nonexistent orders and let's say only B did not self Close
and ended up at [0] but crucially, we would be the original OrdersTotal-1 position of [4]...

Above is not easy to explain - write it out and you see better.
*/


#include <WinUser32.mqh>

bool bShowTimeTaken = FALSE;					//set TRUE to get milliseconds taken to execute print out

int iSlippage = 5;										//Value of the maximum price slippage in points



int start()
{
	int iTotal = OrdersTotal();
	int iPos = 0;

	Print("Closing \"ALL\" Trading Pool Orders. OrdersTotal( ",iTotal," )");
	if(MessageBox("\n\nClose ALL Client Terminal Open + Pending Orders ?\n\n\tARE  YOU  SURE ?\n\n"
								,StringConcatenate("Closing \"ALL\" Trading Pool Orders. OrdersTotal( ",iTotal," )")
								,MB_YESNO|MB_ICONQUESTION) == IDNO)
	{
		Print("By user request: NO orders closed");
		return(-1);
	}
	
  if(bShowTimeTaken) int iStart = GetTickCount();
	
	for (iPos=iTotal-1;iPos>=0;iPos--)	//ALWAYS close [hi]..[lo] order
	{
		while(!IsTradeAllowed())					//paranoia rules...
			Sleep(5000);

		RefreshRates();										//paranoia rules...

		if(OrderSelect(iPos,SELECT_BY_POS,MODE_TRADES))
		{
			switch(OrderType())
			{   
				case OP_BUY:
					OrderClose(OrderTicket(),OrderLots(),MarketInfo(OrderSymbol(),MODE_BID),iSlippage,Violet);
					//Print("#",OrderTicket()," OP_BUY closing, GetLastError()=",GetLastError());
					break;
				case OP_SELL:
					OrderClose(OrderTicket(),OrderLots(),MarketInfo(OrderSymbol(),MODE_ASK),iSlippage,Violet);
					//Print("#",OrderTicket()," OP_SELL closing, GetLastError()=",GetLastError());
				break;
				default: //pending orders
					OrderDelete(OrderTicket());
					//Print("#",OrderTicket()," PENDING deleted, GetLastError()=",GetLastError());
				break;
			}
		}
	}

  if(bShowTimeTaken) {
  	int iEnd = GetTickCount();
	  Print("Close ",iTotal," orders time is ", iEnd-iStart, " milliseconds.");
	}
	
	Print("By user request: ",iTotal," Market + Pending orders closed");

	return(0);
}


/*
2008.06.17 11:45:42	_AAA_CloseAll_ORDERS GBPUSD,Daily: removed
2008.06.17 11:45:42	_AAA_CloseAll_ORDERS GBPUSD,Daily: uninit reason 0
2008.06.17 11:45:42	_AAA_CloseAll_ORDERS GBPUSD,Daily: By user request: NO orders closed
2008.06.17 11:45:40	_AAA_CloseAll_ORDERS GBPUSD,Daily: Closing "ALL" Trading Pool Orders. OrdersTotal( 0 )
2008.06.17 11:45:40	_AAA_CloseAll_ORDERS GBPUSD,Daily: loaded successfully
-----
2008.06.17 11:45:12	_AAA_CloseAll_ORDERS GBPUSD,Daily: removed
2008.06.17 11:45:12	_AAA_CloseAll_ORDERS GBPUSD,Daily: uninit reason 0
2008.06.17 11:45:12	_AAA_CloseAll_ORDERS GBPUSD,Daily: By user request: 0 Market + Pending orders closed
2008.06.17 11:44:59	_AAA_CloseAll_ORDERS GBPUSD,Daily: Closing "ALL" Trading Pool Orders. OrdersTotal( 0 )
2008.06.17 11:44:59	_AAA_CloseAll_ORDERS GBPUSD,Daily: loaded successfully
*/